package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````"!H!`#0```"<B0```@(`!30`(``(
M`"@`'``;``$``'#8A0``V(4!`-B%`0`(````"`````0````$````!@```#0`
M```T``$`-``!```!`````0``!0````0````#````-`$``#0!`0`T`0$`$P``
M`!,````$`````0````$````````````!`````0#DA0``Y(4```4```````$`
M`0```.2%``#DA0(`Y(4"`&`"``"L$@``!@```````0`"````\(4``/"%`@#P
MA0(`*`$``"@!```&````!`````0```!(`0``2`$!`$@!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!`````O;&EB+VQD
M+6QI;G5X+G-O+C,```0````0`````0```$=.50```````@````8````@````
M!````!0````#````1TY5`+.0M2N_$GWI[M+WS)O.](;AQG(480````4````@
M````"@```*`2``@"1!$@``)``%8`<!C""``P"``0$0``$`(`*`````````!(
M`B`*``H`!(0"J$`(!6!I`(0)/D(\EP`!``@D6(`$"6`,DW@)0EH`0`!```$`
M0@D`0(",P(0``!"0$(,)``@!$("!0$#""8`L0)@"00`@`"`$"8"0`20.EW9`
M!0`````````&````!P````D`````````````````````````"@````P````-
M````#P```!`````1````$P```!8`````````````````````````&````!L`
M```<`````````"`````A````(@`````````C````)````"@`````````*@``
M````````````*P```"P````M````+@`````````R````,P`````````W````
M```````````X````.P```#P`````````/0```#X```!`````0@```$4`````
M````1P```$@```!)````2@````````!+````````````````````````````
M````````3````$T`````````3P````````!1````4P```%4`````````````
M````````````5@```%H`````````7`````````!>`````````&````!A````
M``````````!C````9````&8```!G````:@```%^6DQRC6N^05MN3',..A_\-
M.I<+TE$$A(%T@@U[\$IK=E0\E,T_#*_W(\X@B0=PTR!TL`+59-1\9J_,9BY.
M/?;;]P!>!J2'_P&O-.C.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`";7.%
MQ<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!39U\
MI]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)BV^VY
MC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`'\/E
M/RR8(M1HNN.2?"'_Y`Z*F-W";WII^I.M!&(WX_#!0_+OR-^%($]7I)N6Q;F<
M0%`;?5\QN((-OMI7&[,!BV^\T$M]=V_C<&H)0]:?(L>H(6)D!WZIG)MBT/J"
M["SVBVM_FGR&\)9\T9\L_.X+4?GSV],=D'6"#4-F2Q`%;++-/*TY#1?J6O&C
MX/M)XE?$&%>26E+]TN\/;L7?'WR0$.DMW_Y(+L6;MLG5LG$`````````````
M````````$0``````````````(````"T``````````````"`````\````````
M```````@````4```````````````(````(X#`````````````!(````5`@``
M```````````2````Z`(`````````````$@```,P"`````````````!(```![
M!```-(@"```````@`!<`\P``````````````$@```,4"`````````````!(`
M``!M`0``/!4!```````2````Y`,``$2(`@``````$``8`'\"````````````
M`!(```"J`@`````````````2````NP0``$"(`@`$````$0`7`"L#````````
M`````!(````'!0``C#\!`,`#```2``T`8`0``/@Q`0`D`0``$@`-`)4#````
M`````````!(```"0`@`````````````2````/`,`````````````$@```/,#
M``"0F`(``````!``&``^!``````````````2````;`0``'0V`0`8"0``$@`-
M`)4$``#H+@$`Z````!(`#0!3!```T#$!`"@````2``T`MP(`````````````
M$@```'H"`````````````!(```!J```````````````2````&`,`````````
M````$@```*@#``!(B`(`!````"$`&`#]`0`````````````2````!`(`````
M````````$@```-H"`````````````!(```#1`P``1(@"```````0`!<`]0(`
M````````````$@```.(```!8%P$``````!(```"_`@`````````````2````
M8`,`````````````$@```/<!`````````````!(````=`@`````````````2
M````J0,``$B(`@`$````(0`8`/X#``"0F`(``````!``&``U`P``8(@"``0`
M```1`!@`"P0``$1$`0`$````$@`-`'T!`````````````!(```#^````````
M```````2````JP0``.1#`0!@````$@`-`.<$``!@-0$`%`$``!(`#0`5!```
M2$0!```````2``X`F0(`````````````$@```'\$```(&@$``````!(`#0#4
M!```I!0!```````2``L`'0$`````````````$@````H#`````````````!(`
M``"L````6(@"``$````1`!@`TP(`````````````$@```(8$``!01`$`!```
M`!$`#P#8`P``1(@"```````0`!@`9P,`````````````$@```'\#````````
M`````!(```"6`0`````````````2````T0``````````````$@```-($``!@
M+@$`-````!(`#0`]`0`````````````2````!@0``)"8`@``````$``8`-H$
M``#4+P$`_`$``!(`#0"S`0`````````````2````:`(`````````````$@``
M`.,!`````````````!(```"0```````````````2````P0$`````````````
M$@```($``````````````!(```"+`0``5(@"``0````1`!@`IP,``$B(`@`$
M````$0`8`)X``````````````!(```#A`@`````````````2````\@,``)"8
M`@``````$``8`/D$``#,-`$`?````!(`#0`.`0`````````````2````(P,`
M````````````$@```'D$```TB`(``````!``%P!Q`P`````````````2````
MOP,``%"(`@`$````$0`8`"P$``!(-0$`&````!(`#0`R`0`````````````2
M````6@$`````````````$@```*(#``#<%P$`+`(``!(`#0!"`0``````````
M```2````3`,`````````````$@```$,#`````````````!(```"D`0``:(@"
M`!,````1`!@``P,`````````````$@```.\"`````````````!(```"'`@``
M```````````2````9@$`````````````$@```(<#`````````````!(```#%
M!```'#,!`+`!```2``T`4P,`````````````$@```'4``````````````!(`
M``"Q`@`````````````2````1P0``$Q#`0!T````$@`-`,(`````````````
M`!(```"Y```````````````2````&P0``-`O`0`$````$@`-`$<!``#@%@$`
M`````!(`````;&EB<&5R;"YS;RXU+C(R`%])5$U?9&5R96=I<W1E<E1-0VQO
M;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]N97=84P!097)L7VUG7W-E
M=`!097)L7W-V7W-E='!V;@!097)L7V%V7V9E=&-H`%!E<FQ?<W9?<V5T<'8`
M4$Q?9&]?=6YD=6UP`'!E<FQ?<G5N`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W
M6%-?9FQA9W,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7W!A<G-E`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!P
M97)L7V%L;&]C`'!E<FQ?9G)E90!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S
M869E<WES;6%L;&]C`&)O;W1?1'EN84QO861E<@!P97)L7V1E<W1R=6-T`%!,
M7W1H<E]K97D`4&5R;%]S>7-?=&5R;0!03%]M96UO<GE?=W)A<`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`&QI8G!T:')E860N<V\N,`!P=&AR
M96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N
M`&QS965K-C0`<F5A9`!L:6)N<VPN<V\N,0!L:6)D;"YS;RXR`&QI8FTN<V\N
M-@!L:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L:6)C+G-O+C8`7U]R96=I
M<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M
M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`
M7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE
M8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C
M:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!L9"UL:6YU>"YS;RXS`%]?<W1A8VM?8VAK7V=U87)D`%]E9&%T
M80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R=%]?`%]?8G-S7V5N9%]?`%]?96YD
M7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA
M;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?
M<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I
M;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R
M;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA
M;'-?4$%27T)/3U0`1TQ)0D-?,BXT`````````````````@`#``(``@`!````
M`@````$``@`"``$``@`!``$``@`"``(``0`"``$``0`!``(``@````(``@`#
M``,``@`!``(````"``(``P`#``(``0`"``$```````$``0`!``(``0`!````
M`@````(``0`!``(``@```````0````$``0````(``P````````````(````"
M``$``0````(``0`"``0``0```````0`"``(``@````(``@`"``(``@`!``(`
M```"``$```````$````!``$`L0,``!`````@````%&EI#0``!``=!0``````
M``$``0#3`0``$````"`````4:6D-```#`!T%`````````0`!`%X"```0````
M`````!1I:0T```(`'04````````LB`(`%0(``$B(`@`43```4(@"`!15``!4
MB`(`%$L``%B(`@`4.0``8(@"`!0M``!HB`(`%%T``"2'`@`6!P``*(<"`!8%
M```LAP(`%A@``#"'`@`6*@``-(<"`!86```XAP(`%CX``#R'`@`66@``0(<"
M`!9%``!$AP(`%EX``$B'`@`66P``3(<"`!8,``!0AP(`%E\``%2'`@`640``
M6(<"`!9"``!<AP(`%C@``&"'`@`6-```9(<"`!9&``!HAP(`%@\``&R'`@`6
M'```<(<"`!8O``!TAP(`%DT``'B'`@`67```?(<"`!9D``"`AP(`%DD``(2'
M`@`65P``B(<"`!8&``",AP(`%E@``)"'`@`64@``E(<"`!8A``"8AP(`%F$`
M`)R'`@`6%```H(<"`!8P``"DAP(`%@(``*B'`@`6"```K(<"`!8=``"PAP(`
M%B,``+2'`@`6:```N(<"`!8H``"\AP(`%B(``,"'`@`65```Q(<"`!8W``#(
MAP(`%F```,R'`@`6'@``T(<"`!9F``#4AP(`%DX``-B'`@`6:P``W(<"`!8_
M``#@AP(`%F4``.2'`@`6"@``Z(<"`!8E``#LAP(`%D```/"'`@`6"P``](<"
M`!9B``#XAP(`%CH``/R'`@`62````(@"`!8F```$B`(`%CT```B(`@`62@``
M#(@"`!9I```0B`(`%A$``!2(`@`6#@``&(@"`!8G```<B`(`%BD``""(`@`6
M'P``)(@"`!85```HB`(`%D<```A`+>EE`0#K"("]Z`3@+>4$X)_E#N"/X`CP
MON58<@$``,:/XA?*C.)8\KSE`,:/XA?*C.)0\KSE`,:/XA?*C.)(\KSE`,:/
MXA?*C.)`\KSE`,:/XA?*C.(X\KSE`,:/XA?*C.(P\KSE`,:/XA?*C.(H\KSE
M`,:/XA?*C.(@\KSE`,:/XA?*C.(8\KSE`,:/XA?*C.(0\KSE`,:/XA?*C.((
M\KSE`,:/XA?*C.(`\KSE`,:/XA?*C.+X\;SE`,:/XA?*C.+P\;SE`,:/XA?*
MC.+H\;SE`,:/XA?*C.+@\;SE`,:/XA?*C.+8\;SE`,:/XA?*C.+0\;SE`,:/
MXA?*C.+(\;SE`,:/XA?*C.+`\;SE`,:/XA?*C.*X\;SE`,:/XA?*C.*P\;SE
M`,:/XA?*C.*H\;SE`,:/XA?*C.*@\;SE`,:/XA?*C.*8\;SE`,:/XA?*C.*0
M\;SE`,:/XA?*C.*(\;SE`,:/XA?*C.*`\;SE`,:/XA?*C.)X\;SE`,:/XA?*
MC.)P\;SE`,:/XA?*C.)H\;SE`,:/XA?*C.)@\;SE`,:/XA?*C.)8\;SE`,:/
MXA?*C.)0\;SE`,:/XA?*C.)(\;SE`,:/XA?*C.)`\;SE`,:/XA?*C.(X\;SE
M`,:/XA?*C.(P\;SE`,:/XA?*C.(H\;SE`,:/XA?*C.(@\;SE`,:/XA?*C.(8
M\;SE`,:/XA?*C.(0\;SE`,:/XA?*C.((\;SE`,:/XA?*C.(`\;SE`,:/XA?*
MC.+X\+SE`,:/XA?*C.+P\+SE`,:/XA?*C.+H\+SE`,:/XA?*C.+@\+SE`,:/
MXA?*C.+8\+SE`,:/XA?*C.+0\+SE`,:/XA?*C.+(\+SE`,:/XA?*C.+`\+SE
M`,:/XA?*C.*X\+SE`,:/XA?*C.*P\+SE`,:/XA?*C.*H\+SE`,:/XA?*C.*@
M\+SE`,:/XA?*C.*8\+SE`,:/XA?*C.*0\+SE`,:/XA?*C.*(\+SE`,:/XA?*
MC.*`\+SE`,:/XA?*C.)X\+SE`,:/XA?*C.)P\+SE`,:/XA?*C.)H\+SE`,:/
MXA?*C.)@\+SE`,:/XA?*C.)8\+SE`,:/XA?*C.)0\+SE\$`MZ>A1G^4DT$WB
M`#"5Y10`C>40$(WE#""-Y1`0C>(,((WB%`"-XAPPC>69___KP"&?Y<`!G^4"
M$*#AZ`H`Z[@QG^4`8-/E``!6X[!!GQ4)```::___ZZ@AG^4``%#CZ`\"Y6``
M``J409_E0?__ZP``E.7>___K86;`Y0``E.7;___K`""@X?XST.4``)3E`C"#
MX_XSPN75___K%#"=Y?XCT.4%,(/B`2""XP<!<^/^(\#E00``B@,!H.%7___K
M`."@X00PH.,0P)WE.$&?Y0`0G.4T`9_E%""=Y00`D.4`$([E!$".Y201G^44
M09_E`0!2XPP0CN7T/P3E"`".Y00PC,+P[P3E`L&,P`P0CL(#``#:!`"3Y`P`
M4^$$`*'E^___&@`0H.,-P8+BZ`\4Y0XPH.$`$(WE`R""X@P1CN?0$)_E=___
MZP!@4.*T,)_E$0``"N@/%.4;___K&!"-XK0`G^7$`P#K``!0XY1PG^4-```*
MZ`\4Y0'__^MC___K'""=Y0`PE>4&`*#A`P!2X10``!HDT(WB\("]Z.@/$^5^
M___K`&"@X>G__^KL#Q?E``!0XP0```IL"@#K[/__ZE@0G^58`)_E/O__ZQ@0
MC>)0`)_EJ`,`ZP``4./L#P?EX___"O/__^KK_O_K`0"@XR+__^M0B`(`X!8!
M`%@7`0!8B`(`5(@"`'2H`@#D1P$`/(@"`.A'`0"4+@$`E$4!`&B(`@#`1@$`
M,$4!``"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1#`G^4$P"WE#`"?Y0PPG^7]
M_O_K6?__ZT1$`0#<%P$`Y$,!`!0PG^44()_E`S"/X`(@D^<``%+C'O\O`?C^
M_^K$;`$`%`$``!PPG^4<`)_E`S!@X`8`4^,>_R^1$#"?Y0``4^,>_R\!$_\O
MX4>(`@!$B`(``````"00G^4D`)_E`1!@X$$1H.&A'X'@P1"PX1[_+P$0,)_E
M``!3XQ[_+P$3_R_A1(@"`$2(`@``````$$`MZ1A`G^4`,-3E``!3XQ"`O1C?
M___K`3"@XP`PQ.40@+WH>X@"`"@`G^4`,)#E``!3XP```!KB___J&#"?Y0``
M4^/[__\*$$`MZ3/_+^$00+WHV___ZNR%`@``````\$\MZ0A=G^53WTWB`#"5
MY1P0@.)<X(#B1#&-Y03`C>($()'D8C@BX",TH.'_/,/C8C0CX`X`4>$$,(SD
M]___&A#`H.,-0*#A-("-XB!PC>((8(WB0."-X@0@N.4$,+?E!!"VY0(P(^`$
M(+3E`3`CX`'`C.(","/@XS^@X5``7.,$,*[E\___&H@<G^4$,)#E`7"@X6.Q
MH.$$8)WE$#"0Y0C`D.4,X)#E!F"#X`!`D.4(@)WE`1"&X`1@D.4.("S@"S`L
MX`B`CN`,D)WE!B`"X`0P`^!D8:#AY!V!X`PP(^`.("+@!W"(X"BLG^4"(('@
M"8",X`=P@^`&,"O@8A&@X>)]A^`",`/@"B"(X!"`G>4!D";@"S`CX`>0">`*
MH(C@`B"#X&>!H.$&,"G@"["*X.>=@N#<JY_E%'"=Y0@@(>`+,(/@Z3V#X`J@
MA^`)(`+@:7&@X1BPG>6XFY_E!F"*X`&@(N`'("C@!J"*X`F0B^`#(`+@8V&@
MX1RPG>7C/8K@`1")X(RKG^4(D"+@`9")X`8@)^!C$:#A"J"+X`,@`N`@L)WE
MXSV)X&B;G^4'("+@"*"*X`&`)N`*H(+@"9"+X`.`".!C(:#A)+"=Y>,]BN`'
M<(G@!H`HX#BKG^4"D"'@!X"(X`J@B^!C<:#A*+"=Y0.0">#C/8C@&(N?Y09@
MBN`!D"G@!Z`BX`:0B>`(@(O@`Z`*X&-AH.$LL)WEXSV)X`$0B.#LFI_E`H`J
MX`&`B.`&H"?@8Q&@X0F0B^`#H`K@,+"=Y>,]B.#(BI_E`B")X`>0*N`!H";@
M`I")X`B`B^`#H`K@8R&@X32PG>7C/8G@!X"(X`:@*N"8FI_E`G`AX`B@BN`)
MD(O@8X&@X3BPG>4#<`?@XSV*X'BJG^4!<"?@!I")X`A@(N`)D(?@"J"+X`-@
M!N!C<:#A/+"=Y>,]B>`"8";@`:"*X$B:G^4'$"C@"J"&X`F0B^!C8:#A0+"=
MY0,0`>#C/8K@**J?Y0@0(>`"D(G@!B`GX`F0@>`*H(O@`R`"X&,1H.%$L)WE
MXSV)X`B`BN#\F9_E!Z`BX`B@BN`!(";@8X&@X0F0B^`#(`+@2+"=Y>,]BN#8
MJ9_E!Y")X`8@(N`(<"'@"J"+X`D@@N`#<`?@XRV"X`%P)^!C,:#A3+"=Y09@
MBN"HF9_E`Z`HX`9@A^#B;8;@8G&@X0F0B^`*(`+@`1")X`@@(N!0D)WE@*F?
MY0>P(^`!((+@YAV"X`J@B>!4()WE!K`+X&B9G^4#L"O@"("*X&:AH.$(@(O@
M"9""X`JP)^!,:9_E`;`KX`,PB>`+,(/@!K"@X>$MB.!8@)WE81&@X09@B.`'
M8(;@7'"=Y6*!H.$!D"K@XCV#X`NPA^`)("+@"'`AX`(@AN`*H(O@`V`GX.,M
M@N!C<:#A!J"*X&`PG>7L:)_EZ)B?Y0>P*.`)D(/@XCV*X`:@H.$!$(G@9)"=
MY0*P*^!B(:#A"Q"!X`9@B>`"D"?@XQV!X`A@AN!C@:#A"3`CX&B0G>4(L"+@
M"J")X`,PAN#A/8/@!Z"*X`&P*^!A<:#AB&B?Y6P0G>6`F)_E"["*X`F0@>#C
M'8O@!K"@X0>@*.`"((G@`Y`JX`D@@N!PD)WE8S&@X0.@)^`&8(G@"&"&X.&=
M@N`!("K@88&@X0(@AN!T$)WE>&"=Y3"HG^4+L('@"J"&X`@0(^`@:)_E!["+
MX`D0(>`!$(O@!K"@X6EQH.'I+8+@!Y`HX`*0*>`#,(K@"3"#X'R0G>7B'8'@
M8B&@X0*@)^`&8(G@"&"&X.&=@^`!,"K@88&@X0,PAN"`$)WEA&"=Y<2GG^4+
ML('@"J"&X`@0(N"T9Y_E!["+X`D0(>`!$(O@!K"@X6EQH.'I/8/@!Y`HX`.0
M*>`"((K@"2""X(B0G>7C'8'@8S&@X0.@)^`&8(G@"&"&X.&=@N`!("K@`B"&
MX&2GG^608)WE88&@X0J@AN",$)WE4&>?Y0NP@>`($"/@`S"*X`:@H.$'L(O@
M"1`AX&EQH.'I+8+@`1"+X`>0*."4L)WEXAV!X`*0*>!B(:#A"3"#X`9@B^`"
ML"?@X9V#X`A@AN`!,"O@88&@X9@0G>6<L)WE"J"!X`,PAN`($"+@Y&:?Y0>@
MBN`)$"'@:7&@X>D]@^`&8(O@`1"*X`>P*."@H)WEP):?Y>,=@>`#L"O@`B"&
MX&,QH.$)D(K@"R""X`.P)^!A8:#AX2V"X`B`B>`+$"'@`:"(X)"6G^6D$)WE
M!K"#X0F0@>`"L`O@!A`#X&*!H.$!L(OAXBV*X*@0G>5HII_E!W")X`B0AN$'
ML(O@"J"!X`*0">`(<`;@!W")X0,PBN!B$:#A`S"'X#RFG^6L<)WEXBV+X`&P
MB.$!D`C@"J"'X`*P"^`&8(K@";"+X6)QH.$&L(O@$*:?Y;!@G>7B/8/@!R"!
MX0.0`N`*H(;@!R`!X`B`BN`"((GA8V&@X>BEG^7C/8O@"+""X+0@G>4&D(?A
M"J""X`.0">`&@`?@`1"*X`B`B>%C(:#AO*6?Y>,]B^`!L(C@N!"=Y0*0AN$*
MH('@`Y`)X`*`!N`'<(K@"(")X6,1H.&0I9_EXSV+X`>PB."\<)WE`9""X0J@
MA^`#D`G@`8`"X`9@BN`(@(GA8W&@X62EG^7C/8O@!K"(X,!@G>4'D('A"J"&
MX`.0">`'@`'@`B"*X`B`B>%C8:#A.*6?Y>,]B^`"L(C@Q""=Y0:0A^$*H(+@
M`Y`)X`:`!^`!$(K@"(")X6,AH.$,I9_EXSV+X`&PB.#($)WE`I"&X0J@@>`#
MD`G@`H`&X`=PBN`(@(GA8Q&@X>"DG^7C/8O@!["(X,QPG>4!D(+A"J"'X`.0
M">`!@`+@!F"*X`B`B>%C<:#AM*2?Y>,]B^`&L(C@T&"=Y0>0@>$*H(;@`Y`)
MX`>``>`"((K@"(")X6-AH.&(I)_EXSV+X`*PB.#4()WE!I"'X0J@@N`#D`G@
M!H`'X`$0BN`(@(GA8R&@X5RDG^7C/8O@`;"(X-@0G>4"D(;A"J"!X`.0">`"
M@`;@!W"*X`B`B>%C$:#A,*2?Y>,]B^`'L(C@W'"=Y0&0@N$*H(?@`Y`)X`&`
M`N`&8(K@"(")X6-QH.$$I)_EXSV+X`:PB.#@8)WE!Y"!X0J@AN`#D`G@!X`!
MX`(@BN`(@(GA8V&@X=BCG^7C/8O@`K"(X.0@G>4&D(?A"J""X`.0">`&@`?@
M"(")X0$0BN!C(:#A`1"(X.,]B^#H@)WEH+.?Y0*@AN$+L(C@`Z`*X`*`!N!C
MD:#A!W"+X.,]@>`($(KA!Q"!X'BSG^7L<)WE":""X0NPA^`#H`K@"7`"X`9@
MB^`'<(KA8X&@X>,=@>`&<(?@3#.?Y?!@G>4(H(GA`S"&X`&@"N`(8`G@`B"#
MX#0SG^4&8(KA`B"&X`-@H.'TL)WEX7V'X&$1H.$!H"C@`S"+X.<M@N`),(/@
M9Y&@X0IP)^#XH)WE";`AX`<P@^`&8(K@\'*?Y?R@G>4(8(;@`K`KX&*!H.$+
ML(;@XBV#X`=PBN#08I_E"*`IX`*@*N`!$(?@"A"!X`:@H.$`<9WEXCV+X&(A
MH.$$L9WE!F"'X`)P*.#C'8'@"6"&X&.1H.$',"/@"J"+X`,PAN`)L"+@X3V#
MX`B@BN`!L"O@88&@X71BG^4($9WE;'*?Y0NPBN`'<('@XQV+X`:PH.$(H"G@
M`B"'X`-P*N`'((+@#'&=Y6,QH.$#H"C@!F"'X`E@AN#A?8+@`2`JX&&1H.$"
M((;@$!&=Y11AG>4<HI_E"["!X`J@AN`)$"/@#&*?Y0BPB^`'$"'@`1"+X`:P
MH.%G@:#AYRV"X`AP*>`"<"?@`S"*X`<P@^`8<9WEXAV!X&(AH.$"H"C@!F"'
MX`E@AN#A?8/@`3`JX&&1H.$#,(;@'!&=Y2!AG>6PH9_E"["!X`J@AN`)$"+@
MH&&?Y0BPB^`'$"'@`1"+X`:PH.%G@:#AYSV#X`AP*>`"((K@`W`GX`=P@N`D
M(9WEXQV!X&,QH.$#H"C@!F""X.%]A^`)8(;@`2`JX&&1H.$H$9WE`B"&X`NP
M@>`)$"/@!V`AX`BPB^#G'8+@-*&?Y2PAG>4&L(O@*&&?Y0J@@N`#,(K@!J"@
MX6>!H.$(<"G@`7`GX`=P@^`P,9WEX2V+X&$1H.$!L"C@!F"#X#0QG>7B?8?@
M"6"&X&*1H.$+("+@"J"#X`(PAN#G+8/@";`AX#@QG>7,8)_E"*"*X`>P*^!G
M@:#AO'"?Y09@@^`!$(;@!V"@X0NPBN`(H"G@`J`JX.(]B^`*$('@0+&=Y3RA
MG>5B(:#A"T"$X`=PBN`"L"C@8Z&@X>,=@>`)<(?@"S`CX`J0(N`&8(3@`W"'
MX`A@AN`!,"G@X7V'X`,PAN#G/8/@81&,X!#`D.4`,(#E`B",X$0QG>4$P)#E
M`$"5Y0=PC.`*X([@!`!3X0@0@.40((#E!'"`Y0S@@.4!```:4]^-XO"/O>A,
M^__K4(@"`)EY@EJAZ]ENW+P;C];!8LH``%#C'O\O`?!'+>FL,)_E`)"3Y0``
M6>,F```*`%#0Y0``5>,]`%43`5"@$P!0H`,3```:`$"9Y0``5.,.```*`8"@
MX0!PH.$)8*#A!2"@X0<0H.$$`*#AM_O_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"'O>@`4*#A`3#UY0``4^,]`%,3^___&@508.#D
M___J!F!IX$9AH.$!`(7B`&"(Y0``A.#PA[WH"0"@X?"'O>A(B`(`<$`MZ0!`
MH.%P8)_E"-!-X@`PEN5H4)_E!#"-Y0T0H.$$`*#AQ/__ZP``4.,,```*`!"=
MY0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($(+/E``!2XP0@`^7[__\:
M[?__Z@0@G>4`,);E`P!2X0$``!H(T(WB<("]Z/;Z_^M0B`(`2(@"`/!/+>D!
M0*#A`"#1Y?11G^4]`%+C`4"!`@`PE>44T$WB`&"@X00`H.$,,(WE)/O_ZP@0
MC>(`<*#A!@"@X9S__^L`@%#B/0``"AW[_^L``%?A-```F@B`G>6LD9_E"(&@
MX0``UN4``%#C/0!0$P$`H!,``*`#!0``"@8`H.$!,/#E``!3XST`4Q/[__\:
M``!FX`)PA^(``(?@`'"9Y?;Z_^L``%#C"`"'YUPAG^52```*`##6Y0`@DN4]
M`%/C``!3$P@0G>4!8(;B`1&2YP`PP>4&```*`2"!X@$PUN0"$*#A``!3XST`
M4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0``%/C`3#BY?O__QH``*#C#""=
MY0`PE>4#`%+A.```&A30C>+PC[WH`3!(X@$@U.0``%+C`2#CY?O__QKR___J
MQ)"?Y0"PF>4`H)OE``!:XR<```H(,*#A"R"@X0```.H*,*#A!!"RY0&@@^(`
M`%'C^O__&@,P@^(#$:#AC#"?Y0`@D^4``%+C"@``"@L`H.&8^O_K``!0XP``
MB>46```*"H&@X0`@H.,!,(KB`R&`YPB@C>6I___J`2"@XP$`H.$`((/EK/K_
MZP`P4.($,(WE"0``"@J!H.$+$*#A"""@X5WZ_^L$,)WE`P"@X0`PB>7K___J
M"!"@X]___^H``.#CPO__ZG+Z_^M0B`(`2(@"`'R(`@#P02WI*%&?Y7C03>(`
M,)7E`'!0XG0PC>4"```*`##7Y0``4^,%```:=""=Y0`PE>4#`%+A/0``&GC0
MC>+P@;WH@OK_ZP!@4.+V__\*!@"@X=7Z_^L``%#C)```"A,PT.4N`%/C)@``
M"A-`@.('`*#ACOK_ZP"`H.$$`*#AB_K_ZP``B.`"`(#B=OK_ZP"`H.&@,)_E
M`"#@XP$0H.,$0(WE`'"-Y8WZ_^L(((WB"!"@X0,`H./%^O_K`0!PXP@`H.$#
M```*&#"=Y0\Z`^(!"5/C%```"C_Z_^L(`*#A'/K_ZP8`H.&P^O_K``!0X]K_
M_QH&`*#AQ/K_ZP<`H.$C^O_KR/__ZA0PT.4``%/CSO__"BX`4^/3__\:%3#0
MY0``4^/)__\*S___ZK3__^OI___J(OK_ZU"(`@#01`$`<$`MZ7!`G^4`4*#A
M``"4Y;'Z_^L%$*#A2B^`X@,`H..G^O_K``!0XP$```H``*#C<("]Z```E.6G
M^O_K.#&0Y0\Z`^(!"5/C!0``"@``E.6A^O_K.#&0Y0\Z`^(*"E/C\?__&@4`
MH.$"$*#C<_K_ZQ`/;^&@`J#A<("]Z%2(`@#P0"WIT%"?Y0':3>(,T$WB`#"5
MY0'*C>($P(SB`&"@X0%PH.&T()_E!!"-XK``G^4`,(SE!/K_ZP``4.,>``#:
M"#"-X@%`0.($((/@!#!2Y0``4^,6```*`$"@X00@H.$O$*#C!`"-XE'Z_^L`
M`%#C$0``"FPPG^4``)/E=OK_ZP0PH.$$((WB!A"@X5KZ_^L!.HWB!#"#X@`@
MD^4`,)7E`P!2X0L``!H!VHWB#-"-XO"`O>@``%3CY___&B0PG^4``)/E9/K_
MZP<@H.$&$*#AVOG_Z^W__^K)^?_K4(@"`/\/``#81`$`5(@"`!!`+>D8,)_E
M``"3Y5?Z_^L00+WH##"?Y0P@G^4,$)_E#?K_ZE2(`@!41`$`/!4!`.A$`0`0
M0"WI.$"?Y0C03>(``)3E2?K_Z^S__^L``)3E1OK_ZP`@H.,<,)_E!""-Y0`P
MC>44()_E%!"?Y1+Z_^L(T(WB$("]Z%2(`@#@1P$`C#\!``1%`0!P0"WIS%"?
MY0+:3>(@T$WB`#"5Y0(JC>(<((+B`#""Y=#Y_^NP,)_E%""-X@D`C>@(((WE
M`@"@X:`PG^6@()_E`1"@X]GY_^L``%#C'```N@$ZC>(@,(/B"#!#X@@`G>4#
M$*#A`2J@XPPPC>69^?_K`$!0XA(``+H!`(3BK?G_ZP!@4.(0```*#!"=Y00@
MH.%I^?_K`#"@XP8`H.$$,,;G`CJ-XAPP@^(`()/E`#"5Y0,`4N$&```:`MJ-
MXB#0C>)P@+WH``"@X_3__^H&`*#A\O__ZFWY_^M0B`(`*$4!`!Q%`0`!$```
MQ/__ZO!/+>G,,9_E`=I-XAS03>(`,)/E`2J-XA0@@N(`0*#A`6"@X;`!G^40
M$(WB`#""Y1/^_^LO$*#C`%"@X00`H.&9^?_K``!0XPT```H$$*#AB`&?Y5W^
M_^L$`*#A`3J-XA0P@^(`()/E:#&?Y0`PD^4#`%+A5@``&@':C>(<T(WB\(^]
MZ`0`H.&!^?_K4!&?Y0"0H.$&`*#AL_G_ZP"P4.+I__\*/'&?Y3R!G^4\H9_E
M/&&?Y0`PV^4``%/C!["@`0``5>,$```*"Q"@X04`H.$)^?_K``!0XRX```H+
M`*#A:_G_ZP`PB^`!,%/E+P!3XP<``!H`P*#C`3!`X@,PB^``P,/E`1!SY0$`
M0.(O`%'C^O__"@$PB>(``(/@"`!0X<G__\K,,)_E`2J@XP$0H.,(0(WE!*"-
MY0"PC>44`(WB7_G_ZP``EN6K^?_K%!"-XDHO@.(#`*#CE?G_ZP``4.,%```:
M``"6Y:/Y_^LX,9#E#SH#X@()4^,*```*8!"?Y0``H.-X^?_K`+"@X0``6^/'
M__\:K/__ZD00G^5R^?_K`+"@X?C__^H!$*#C%`"-XFKY_^L``%#C[___&A00
MC>(8`)_E`?[_ZQ0`C>)"^?_KH?__ZO+X_^M0B`(`,$4!`#Q%`0!,10$`+$4!
M`/\/``!810$`5(@"`%!%`0``,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!,-+D
M``!3X_K__QH>_R_A<$`MZ0!`4.(I```*`%#4Y0``5>,F```*%/G_ZP$`0.(`
M((3@`@!4X0L``"H`,-3G+P!3XR@``!H!,$+B`P``Z@`0T^4!,$/B+P!1XR(`
M`!H$`%/A`R"@X?C__QH"`%3A*```"@$@0N($``#J`##2Y0$00N(O`%/C`@``
M&@$@H.$"`%3A^/__.@(@9.`",(+B`0I3XPX``(H!((+B!!"@X0$ZH.-P`)_E
ML?C_ZV@`G^5P@+WH`@"@X]KX_^L`,%#B`P``"BX@H.,#`*#AL"##X7"`O>@`
M`*#C<("]Z`$P0N(#``#J`!#3Y0$P0^(O`%'CV___"@,`5.$#(*#A^/__.@(`
M5.'6__\:+P!5X^C__PIP0+WH!`"?Y>;X_^J`B`(`6$4!`!!`+>E,X9_E,-!-
MX@C`C>(/`+[H#P"LZ`\`ON@/`*SH-$&?Y0`@GN4`,)3E+`&?Y;`@S.$L,(WE
M</W_ZR`!G^5N_?_K'`&?Y6S]_^L8`9_E:OW_ZQ0!G^5H_?_K$`&?Y6;]_^L,
M`9_E9/W_ZP@!G^5B_?_K!`&?Y6#]_^L``9_E7OW_Z_P`G^5<_?_K^`"?Y5K]
M_^OT`)_E6/W_ZP00C>+L`)_E)/W_ZP`04.(!```*R`"?Y7/]_^L$$(WBU`"?
MY1W]_^L`$%#B`0``"L@`G^5L_?_K!!"-XL``G^46_?_K`!!0X@H```J(`)_E
M9?W_ZZP0G^5T`)_E8OW_ZRP@G>4`,)3E`P!2X1$``!HPT(WB$("]Z`00C>*(
M`)_E!OW_ZP`04.("```*3`"?Y57]_^ON___J"B"@XVP0G^49`(WBS/C_ZP``
M4./H__\:(Q"-XO3__^I`^/_K8$0!`%"(`@!<10$`:$4!`'!%`0!\10$`A$4!
M`)1%`0`P10$`H$4!`*Q%`0"X10$`/$4!`,1%`0#010$`W$4!`/!%`0`$1@$`
M$$8!`$!&`0`@1@$`-$8!`#!`+>ED4)_E9$"?Y0``E>4`,)3E#-!-X@$`<.,$
M,(WE!0``"@0@G>4`,)3E`P!2X0T``!H,T(WB,("]Z`T0H.$P`)_ET/S_ZP``
M4.,$```*``#0Y3``4.,``%`3`0"@$P``H`,``(7E[?__Z@[X_^L\B`(`4(@"
M`*!%`0`00"WIZ/?_Z^'W_^L``%#C``"0%1"`O>CP1RWI^."?Y3C03>(8P(WB
M`'"@X0\`ON@/`*SH!P">Z."`G^480)WE`#"8Y0``5.,'`(SH-#"-Y1<```H8
M4(WBQ)"?Y08``.H'$*#AQ/?_ZP``4.,6```*!$"UY0``5.,-```*%!"-X@0`
MH.&A_/_K`&!0X@(```H`,-;E``!3X_#__QH$`*#A!Q"@X>S\_^L$0+7E``!4
MX_'__QHT()WE`#"8Y0,`4N$4```:.-"-XO"'O>@'`*#A$OC_ZP"@H.$&`*#A
M#_C_ZP``BN`"`(#B^O?_ZP"@H.$(8(WE@`*-Z"@PG^4`(.#C`1"@XQ'X_^L*
M$*#A!`"@X='\_^O5___JQ/?_ZX1$`0!0B`(`3$4!`%!%`0#P3RWII,B?Y0+9
M3>+\T$WB)#"-X@Q`C.(\X(WB`&"@X0<`G.@'`(/H#P"TZ`\`KN@#`)3H>+B?
MY23`C.(P,(WB`$";Y0,`CN@'`)SH!P"#Z`(YC>+T,(/B(!"-XE0(G^4`0(/E
M7OS_ZP!`4.("```*`##4Y0``4^,"`0`:E/__ZP!P4.(P0(T"1P``"@<`H.'7
M]__K@`"@X0$`@.+"]__K`##7Y0!0H.$``%/C`$"@$0D```H`,(WE!`"@X?@W
MG^4`(.#C`1"@X]7W_^L!,/?E`D"$X@``4^/U__\:/`"=Y0``4.,\0(T2`P``
M&A```.H$`+3E``!0XPT```H@$(WB-_S_ZP!P4.+X__\*`##7Y0``4^/U__\*
M6/W_ZP``4./R__\*!P"@X</W_^L`D%#B*0``&B1`G>4``%3C)0``"@`PU.4`
M`%/C`7"@$PD``!H@``#J^#"-X@<Q@^#40!/E``!4XQL```H`,-3E`7"'X@``
M4^,7```*!`"@X3_]_^L``%#C\O__"@0`H.&J]__K``!0X^[__PH`D*#A#@``
MZJ7W_^L``%#CM```&@0`E.0``%#CMP``"B`0C>((_/_K`#!0XOC__PH`,-/E
M``!3X_7__PKQ___J`)"@XPD`H.&#]__K`$"@X04`H.&`]__K``"$X`%+@.($
M0(3B!`"@X6GW_^L`<*#AL#:?Y;"&G^4(,(WE`"#@XZ@VG^4!$*#C#%"-Y0"0
MC>4$@(WE?/?_ZP<`H.$'':#CA??_ZP$`<.,9```*@%:?Y0``E>7"]__K!Q"@
MX4HO@.(#`*#CN/?_ZP``4.,>```*8":?Y0`PEN4``)+E`1"@XP!PC>50)I_E
MA??_ZP``H.,".8WB]#"#X@`@D^4`,)OE`P!2X8(!`!H"V8WB_-"-XO"/O>A9
M]__K`""0Y1$`4N/A__\*#!:?Y0`PEN4``)'E!""-Y0!PC>4`)I_E`1"@XV_W
M_^L``*#CZ/__Z@``E>6;]__K.#&0Y0\Z`^(!"5/CVO__&@``E>65]__K0)&0
MY=SV_^L``%GAU/__&@``E>6/]__K.#&0Y8,[H.$.`E/CSO__&@0`H.$=]__K
M(!"-X@!0H.&8!9_EI_O_ZP``4.-5```*`$"6Y3GW_^L`$*#A!`"@X7_]_^L`
M0%#B3@``"@0`H.$@]__K`P!0XP"0H.$+``#:!`!`X@``A.!4%9_EL_;_ZP``
M4.,%```:!`!9XPD!``H)D(3@!3!9Y2\`4^,%`0`*J?[_ZP`04.($```:!`"@
MX??V_^L`,%#B&#"-Y3<``!H0%9_E$`6?Y=7[_^O_]O_K")6?Y0@`C>6``8WH
M#)"-Y?PTG^4`(.#C`1"@XP4`H.$(]__K`&"@XPX``.H"]__K`#"0Y1$`4^,0
M```:[_;_ZP%@AN((`(WE#&"-Y1"0C>6``8WH!""@X;@TG^4!$*#C!0"@X??V
M_^L'':#C!0"@X0#W_^L!`'#C`$"@X>K__PH'`*#AC/;_ZP40H.%(!)_EK_O_
MZP4`H.&<_O_K!0"@X8'__^H`<*#A`/__ZI?^_^L$`*#AZ?;_ZWO__^H-`*#C
M5'2?Y?W^_^H`0);EKO__Z@)`H.,`,.#C$2#@XP!`C>6N]O_K]!"-X@8@H.,8
M`)WE:/;_Z_0PW>4``%/C`@``&O4PW>5#`%/CSP``"@!`H.,`(*#C`#"@XP!`
MC>48`)WEGO;_Z_3#G^7T`Y_E]!.?Y?0CG^7T,Y_E:$"-Y6Q`C>6P0(WE5,"-
MY5@`C>5<$(WE8""-Y60PC>5PD(WB'%"-Y0(IH./T$(WB&`"=Y4GV_^L`8%#B
M-P``VF@PG>6P`)WEAB&#X`(`4^%L,)WE:""-Y0$P@X*F/H/@``!0XVPPC>4J
M```*0*!@X@H`5N$&H*"Q``")X`H@H.'T$(WB1/;_Z[`PG>4#,(K@0`!3X[`P
MC>7B__\:]#"-XE0`C>(&8&K@"J"#X+WW_^L_`%;C$```V@90H.%`0(KB0!!$
MXD`@H.,)`*#A,O;_ZT!01>)4`(WBLO?_ZS\`5>-`0(3B]?__RD!@1N(F,Z#A
M`2"#X@-C1N`"HXK@"A"@X40PH.,&(*#A"0"@X4SV_^NP8(WEP___ZO2@C>+C
M___J&`"=Y1Q0G>6]]O_K?R#@XVA@G>5P0(WBIC&@X3\P`^(!$(/B.`!1XVR0
MG>4#(,3G9```R@$`A.`X(&'B`!"@XWGV_^LI/*#AJ##-Y2DXH.$F+*#A5`"-
MXJN0S>6O8,WE*92@X:DPS>4F.*#A)F2@X:J0S>6L(,WEK3#-Y:Y@S>6`]__K
M5!"=Y5@@G>4AQ*#A7`"=Y;;`S>4BS*#AN,#-Y2+$H.$AZ*#A(3R@X;<0S>6Z
MP,WE8!"=Y2#,H.&_`,WEO,#-Y2#(H.$@!*#AM>#-Y;L@S>4BZ*#AO@#-Y60@
MG>4A#*#APQ#-Y<``S>4A"*#A(12@X<$`S>7"$,WE(@R@X2(8H.''(,WE(B2@
MX<B@C>+&(,WE^""-X@I`H.&T,,WEN>#-Y;W`S>7$`,WEQ1#-Y;1@C>(QD$+B
M````Z@$P]N4`,(WE!`"@X3@QG^4`(.#C`1"@XR7V_^L&`%GA`D"$XO7__QH`
M`*#C2#&?Y?``S>4,,(WE@`6-Z%PQG^4`(.#C`1"@XP4`H.$8]O_K)?__Z@1@
MEN4``%;C]O[_"@8`H.$&]O_K`P!0X_+^_YH$`$#B``"&X"01G^6:]?_K``!0
MXP9`H`'K_O_J0"!AX@$`A.``$*#C%/;_ZU0`C>(I]__K!`"@X3@@H.,`$*#C
M#O;_ZY/__^KV,-WE00!3XRS__QKW,-WE0P!3XRG__QKX,-WE2`!3XR;__QKY
M,-WE10!3XR/__QH`0(WE&$"=Y0`PX.,Y(.#C!`"@X<+U_^OT$(WB!`"@X2D@
MH.-\]?_K9#"?Y?0@C>((((WE##"-Y8`!C>AT,)_E`"#@XP$0H.,%`*#AWO7_
MZ^O^_^J4]?_KH$0!`%"(`@`P10$`3$8!`&!&`0!810$`5$8!`%2(`@!@B`(`
MZ$8!`&A&`0`T2`$`I$8!`$!&`0"@10$`X$<!`,1&`0#41@$`1$8!``$C16>)
MJ\WO_MRZF'94,A#PX=+#M$8!`*Q&`0#P3RWI?#.?Y7QSG^4`,)/E#-!-X@``
ME^4$,(WE"/;_ZP$PH.,-$*#A83#`Y5P#G^4E^O_K``!0XP(```H`,-#E,0!3
MXX8```K0_/_K``"7Y?OU_^L+,*#C`2"@XS`3G^61]?_K``!0XRACG^4N```*
M]#\6Y0P@D.4!`%/C&("2Y2D``-H`4*#C`4"@X_B2G^4)``#J#!"1Y0L`H.$H
M]?_K``!0X_0_%N4<```:`4"$X@0`4^$!4(7B&```V@``E^7?]?_K`#"@XP4@
MH.$($*#ANO7_ZP"@4.(/```*`!":Y;0RG^4(P)'E\`\6Y0PP`^`!"U/C!+&0
MY^7__PH``)GES_7_ZP`0FN4",*#C`""@XTWU_^L`$*#AWO__ZO0_%N4!($/B
M!0!2X4$```H``)?EP_7_ZP,PH.,!(*#C7!*?Y5GU_^L`0%#B/%*?Y0H```H`
M`)7ENO7_ZPPPE.5`(I_E`!"3Y2_U_^L,,)3E`#"3Y0@PD^4!!1/C<P``&@``
ME^6O]?_K`S"@XP$@H.,4$I_E1?7_ZP!04.+L09_E"@``"@T0H.$``I_EQ_G_
MZP"`4.(``)3E3```"J'U_^L,,)7E"""@X0`0D^46]?_K``"7Y9OU_^L`,*#C
M#1"@X6$PP.7(`9_EN/G_ZP``4.,`0*#A[`\&Y9"1G^68@9_E'```"@<=H.-,
M]?_K`3"`XA$`4.,!`%,350``BF@QG^4$()WE`#"3Y0,`4N%/```:#-"-XO"/
MO>@!`%/CN___V@%`H.,``)?E?O7_ZP@0H.'.]/_K]#\6Y0%`A.($`%/A]___
MRK'__^H!,-#E``!3XW;__PIT___J\`\8Y1K]_^L``%#C[`\(Y38```H,()7E
M"#&?Y0`@DN4($)+E`3`#X`$+4^,A```:#`"2Y?!/%N4$$*#AN_3_ZPP@E>7<
M,)_E`""2Y0!@H.$($)+E`$"4Y0$P`^`!"U/C"P``&@P@DN4&,*#A!!"@X<@`
MG^4*]?_K5/7_Z_`O%N4,,)7E`!"2Y0``D^6X^O_KL/__Z@``E^5,]?_K#""5
MY0(PH.,`$)+E`""@X\GT_^L`(*#AZ___Z@``F>5#]?_K##"5Y00@H.$`$)/E
M`C"@X\#T_^O6___J``"5Y3OU_^L,,)3E`!"3Y0+U_^N%___J3`"?Y>KT_^N>
M]/_K\"\8Y0`PH.$`$)+E.`"?Y00@H.'C]/_K4(@"`%2(`@"$10$`/$<!`'2H
M`@``!"``1$<!`$A'`0!01P$`/$4!`#!%`0!X1P$`5$<!`*!'`0!P0"WI`%"@
MX:?[_^L`,-#E`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:
M4?S_ZP``5>,``%`3<("]"``PU>4``%/C<("]"!@0G^4$`*#A1O3_ZP``5.%P
M@+T8!0"@X7!`O>C^^?_J8$8!`!0PG^44P)_E`S"/X`PPD^<``%/C`#"3%6GT
M_^I(0P$`&`$``/!'+>E,8)_E3%"?Y09@C^`%4(_@!F!EX`!PH.$!@*#A`I"@
MX27T_^M&8;#A\(>]"`!`H.,!0(3B!#"5Y`D@H.$($*#A!P"@X3/_+^$&`%3A
M]___&O"'O>CP00$`Z$$!`![_+^$(0"WI"("]Z`$``@!P97)L>'-I+F,```!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````42`$`)$@!`"Q(
M`0`T2`$`/$@!`%!(`0``````#$@!`"Q%`0``````!$8!``A&`0``2`$`-$4!
M``A(`0``````[$<!`/1'`0``````)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!
M4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,
M3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````4UE35$5-```E,#)X
M`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``<&%R;```
M```N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E
M<W1E;7`M)74M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!!4D=6`````!@```!P97)L`````#````!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M
M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<```
M``!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`````1%E,
M1%],24)205)97U!!5$@```!32$Q)0E]0051(``!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M
M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`[
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D[
M"GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I
M;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!
M4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]
M+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%2
M1U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6
M>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE;F%M
M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I;FUO
M9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM;V0@
M,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R:6YT
M("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF
M;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1
M)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*
M<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H)&]U
M="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]
M*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D9FEL
M96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G/"<L
M("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]
M"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U
M;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D
M;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%
M3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A
M('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A0
M05(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN
M960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U
M:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G
M<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@
M;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D
M9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#
M8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T
M<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@
M)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X[
M"F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I
M;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI
M=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP
M<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM
M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].
M('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V
M97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@
M:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I
M;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M
M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R
M+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL
M:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92![
M"F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S
M=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%
M3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE
M*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@
M)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D
M9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I
M.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D
M9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1E>'0L("1C
M<F,I(#T@0%\["FUY("@D9F@L("1F:6QE;F%M92D["B1F:6QE;F%M92`]("(D
M<&%R7W1E;7`O)&-R8R1E>'0B.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["G5N
M;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PIP=7-H($!T;7!F:6QE
M+"`D9FEL96YA;64["GT*96QS92!["G)E='5R;B`H=6YD968L("1F:6QE;F%M
M92D@:68@*"UR("1F:6QE;F%M92D["GT*;W!E;B`D9F@L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FXH)&9H+"`D9FEL
M96YA;64I.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.
M5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N
M*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF
M("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!
M4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE
M+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`#"4_W\!`````````/@:`0#0&@$```````$`
M```!`````0```-,!```!````(@(```$````N`@```0```#D"```!````0P(`
M``$```!1`@```0```%X"```!````L0,```P```"D%`$`#0```$A$`0`9````
MY(4"`!L````$````&@```.B%`@`<````!````/7^_V^,`0$`!0```/P+`0`&
M````/`4!``H````G!0``"P```!`````5``````````,````8AP(``@```!`"
M```4````$0```!<```"4$@$`$0```%P2`0`2````.````!,````(````_O__
M;_P1`0#___]O`P```/#__V\D$0$`````````````````````````````````
M````````````````````````````````\(4"````````````L!0!`+`4`0"P
M%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4
M`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!
M`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`
ML!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P
M%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4
M`0"P%`$`L!0!`+`4`0"P%`$`L!0!`+`4`0"P%`$``````#B(`@``````````
M`/____]<2`$`1T-#.B`H1TY5*2`U+C,N,2`R,#$V,#0Q.0!'0T,Z("A'3E4I
M(#4N,RXQ(#(P,38P-3`S`$$I````865A8FD``1\````%-50`!@,(`0D!$@03
M`10!%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M````````````````````````````````````````````"P````$````"````
M-`$!`#0!```3```````````````!`````````!,````'`````@```$@!`0!(
M`0``(```````````````!``````````A````!P````(```!H`0$`:`$``"0`
M``````````````0`````````-````/;__V\"````C`$!`(P!``"P`P``!0``
M```````$````!````#X````+`````@```#P%`0`\!0``P`8```8````!````
M!````!````!&`````P````(```#\"P$`_`L``"<%``````````````$`````
M````3@```/___V\"````)!$!`"01``#8````!0`````````"`````@```%L`
M``#^__]O`@```/P1`0#\$0``8`````8````#````!`````````!J````"0``
M``(```!<$@$`7!(``#@````%``````````0````(````<P````D```!"````
ME!(!`)02```0`@``!0````P````$````"````'P````!````!@```*04`0"D
M%```#```````````````!`````````!W`````0````8```"P%`$`L!0``"P#
M``````````````0````$````@@````$````&````W!<!`-P7``!L+```````
M```````$`````````(@````!````!@```$A$`0!(1```"```````````````
M!`````````".`````0````(```!01`$`4$0``(A!``````````````0`````
M````E@````$``'""````V(4!`-B%```(````#0`````````$`````````*$`
M```!`````@```."%`0#@A0``!```````````````!`````````"K````#@``
M``,```#DA0(`Y(4```0```````````````0`````````MP````\````#````
MZ(4"`.B%```$```````````````$`````````,,````!`````P```.R%`@#L
MA0``!```````````````!`````````#(````!@````,```#PA0(`\(4``"@!
M```&``````````0````(````T0````$````#````&(<"`!B'```<`0``````
M```````$````!````-8````!`````P```#2(`@`TB```$```````````````
M!`````````#<````"`````,```!(B`(`1(@``$@0``````````````@`````
M````X0````$````P`````````$2(```T```````````````!`````0```.H`
M```#``!P``````````!XB```*@```````````````0`````````!`````P``
A````````````HH@``/H```````````````$`````````
